pub enum TimsDataLoader {
InMemory(TimsInMemoryLoader),
Lazy(TimsLazyLoder),
}Variants
InMemory(TimsInMemoryLoader)
Lazy(TimsLazyLoder)
Implementations
Sourceimpl TimsDataLoader
impl TimsDataLoader
pub fn new_lazy( bruker_lib_path: &str, data_path: &str, use_bruker_sdk: bool, scan_max_index: u32, im_lower: f64, im_upper: f64, tof_max_index: u32, mz_lower: f64, mz_upper: f64, ) -> Self
pub fn new_in_memory( bruker_lib_path: &str, data_path: &str, use_bruker_sdk: bool, scan_max_index: u32, im_lower: f64, im_upper: f64, tof_max_index: u32, mz_lower: f64, mz_upper: f64, ) -> Self
Sourcepub fn new_lazy_with_calibration(
data_path: &str,
tof_max_index: u32,
mz_lower: f64,
mz_upper: f64,
im_lookup: Vec<f64>,
) -> Self
pub fn new_lazy_with_calibration( data_path: &str, tof_max_index: u32, mz_lower: f64, mz_upper: f64, im_lookup: Vec<f64>, ) -> Self
Create a lazy loader with pre-computed ion mobility calibration lookup table.
This method enables accurate ion mobility calibration with fast parallel extraction. The im_lookup table should be pre-computed using the Bruker SDK.
Arguments
data_path- Path to the .d foldertof_max_index- Maximum TOF index (from GlobalMetaData)mz_lower- Minimum m/z value (from GlobalMetaData)mz_upper- Maximum m/z value (from GlobalMetaData)im_lookup- Pre-computed scan→1/K0 lookup table
Returns
A new TimsDataLoader with LookupIndexConverter
Sourcepub fn new_in_memory_with_calibration(
data_path: &str,
tof_max_index: u32,
mz_lower: f64,
mz_upper: f64,
im_lookup: Vec<f64>,
) -> Self
pub fn new_in_memory_with_calibration( data_path: &str, tof_max_index: u32, mz_lower: f64, mz_upper: f64, im_lookup: Vec<f64>, ) -> Self
Create an in-memory loader with pre-computed ion mobility calibration lookup table.
This method enables accurate ion mobility calibration with fast parallel extraction. The im_lookup table should be pre-computed using the Bruker SDK.
Arguments
data_path- Path to the .d foldertof_max_index- Maximum TOF index (from GlobalMetaData)mz_lower- Minimum m/z value (from GlobalMetaData)mz_upper- Maximum m/z value (from GlobalMetaData)im_lookup- Pre-computed scan→1/K0 lookup table
Returns
A new TimsDataLoader with LookupIndexConverter
Sourcepub fn new_lazy_with_mz_calibration(
data_path: &str,
tof_intercept: f64,
tof_slope: f64,
im_min: f64,
im_max: f64,
scan_max_index: u32,
) -> Self
pub fn new_lazy_with_mz_calibration( data_path: &str, tof_intercept: f64, tof_slope: f64, im_min: f64, im_max: f64, scan_max_index: u32, ) -> Self
Create a lazy loader with full calibration (both m/z and IM).
This method uses regression-derived m/z calibration coefficients instead of the simple boundary model, providing more accurate m/z conversion.
Arguments
data_path- Path to the .d foldertof_intercept- Intercept for sqrt(mz) = intercept + slope * toftof_slope- Slope for sqrt(mz) = intercept + slope * tofim_min- Minimum 1/K0 valueim_max- Maximum 1/K0 valuescan_max_index- Maximum scan index
Sourcepub fn new_in_memory_with_mz_calibration(
data_path: &str,
tof_intercept: f64,
tof_slope: f64,
im_min: f64,
im_max: f64,
scan_max_index: u32,
) -> Self
pub fn new_in_memory_with_mz_calibration( data_path: &str, tof_intercept: f64, tof_slope: f64, im_min: f64, im_max: f64, scan_max_index: u32, ) -> Self
Create an in-memory loader with full calibration (both m/z and IM).
This method uses regression-derived m/z calibration coefficients instead of the simple boundary model, providing more accurate m/z conversion.
pub fn get_index_converter(&self) -> &dyn IndexConverter
Sourcepub fn uses_bruker_sdk(&self) -> bool
pub fn uses_bruker_sdk(&self) -> bool
Check if the Bruker SDK is being used for index conversion. The Bruker SDK is NOT thread-safe, so parallel operations that call the index converter must be disabled when using the SDK.